﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Charts;

namespace CollectionOfCollectionsSource
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            PriceDataHistory hist = new PriceDataHistory(5);
            GenerateSeriesFromPriceHistory(hist, xamDataChart1);

        }


        public void GenerateSeriesFromPriceHistory(PriceDataHistory data, XamDataChart chart)
        {
            var goupedPriceHistory =
                (from i in data
                 group i by i.LocationCode into location
                 select new
                 {
                     LocationConde = location.Key,
                     Data = location.ToList<PriceData>()
                 }).ToList();

            foreach (var item in goupedPriceHistory)
            {
                LineSeries series = new LineSeries();
                series.Title = item.LocationConde;
                series.XAxis = xAxis;
                series.YAxis = yAxis;
                series.MarkerType = MarkerType.None;
                series.ItemsSource = item.Data;
                series.ValueMemberPath = "Price";

                if (xAxis.ItemsSource == null || xAxis.ItemsCount < 1)
                    xAxis.ItemsSource = item.Data;

                chart.Series.Add(series);
            }
        }
    }

    public class PriceDataHistory : ObservableCollection<PriceData>
    {
        public PriceDataHistory(int groupCount)
        {
            Random r = new Random();

            Add(new PriceData
            {
                Price = r.Next(200, 500),
                Date = DateTime.Now,
                LocationCode = "Location " + 0
            });

            for (int i = 1; i < 2000; i++)
            {
                double price = this[i - 1].Price;

                if (r.NextDouble() > 0.5)
                {
                    price += r.NextDouble();
                }
                else
                {
                    price -= r.NextDouble();
                }
                
                Add(new PriceData
                {
                    Price = price,
                    Date = DateTime.Now.AddDays(i),
                    LocationCode = "Location " + (i % groupCount)
                });
            }
        }
    } 

    public class PriceData
    {
        public string Country { get; set; }
        public string LocationCode { get; set; }
        public DateTime Date { get; set; }
        public double Price { get; set; }
    }
}
